@@ -46,6 +46,6 @@ for my $i (0 .. $#text)
 
 	$result = $parser -> parse(\$text);
 
-	print join("\n", @{$parser -> tree2string}), "\n";
+	print join("\n", @{$parser -> tree -> tree2string}), "\n";
 	print "Parse result: $result (0 is success)\n";
 }
